@@ -23,17 +23,27 @@ module Gem2Deb
   end
 
   SUPPORTED_RUBY_VERSIONS = {
+
     #name             Ruby binary
     #---------------  -------------------
-    'ruby1.8'   => '/usr/bin/ruby1.8',
     'ruby1.9.1' => '/usr/bin/ruby1.9.1',
-  }
+    'ruby2.0'   => '/usr/bin/ruby2.0',
+
+  }.select do |version, binary|
+    # To help backporters without having to also backport the interpreters.
+    File.exists?(binary)
+  end
 
   RUBY_CONFIG_VERSION = {
-    'ruby1.8'   => '1.8',
     'ruby1.9.1' => '1.9.1',
+    'ruby2.0'   => '2.0',
   }
 
+  SUPPORTED_RUBY_SHARED_LIBRARIES = [
+    'libruby1.9.1',
+    'libruby2.0',
+  ]
+
   RUBY_SHEBANG_CALL = '/usr/bin/env ruby'
 
   BIN_DIR = '/usr/bin'
@@ -42,13 +52,19 @@ module Gem2Deb
 
   LIBDIR = File.expand_path(File.dirname(__FILE__))
 
-  def run(cmd)
-    puts(cmd) if $VERBOSE
-    system(cmd)
+  def run(*argv)
+    puts(_format_cmdline(argv)) if $VERBOSE
+    system(*argv)
     if $?.exitstatus != 0
-      raise Gem2Deb::CommandFailed, "[#{cmd} failed!]"
+      raise Gem2Deb::CommandFailed, _format_cmdline(argv)
     end
   end
+
+  private
+
+  def _format_cmdline(argv)
+    argv.map { |a| a =~ /\s/ && a.inspect || a }.join(' ')
+  end
 end
 
 require 'gem2deb/version'
