@@ -135,11 +135,9 @@ module Gem2Deb
         return
       end
 
-      cmd = "#{SUPPORTED_RUBY_VERSIONS[rubyver]} -I#{LIBDIR} #{TEST_RUNNER}"
-      puts(cmd) if $VERBOSE
-      system(cmd)
-
-      if $?.exitstatus != 0
+      begin
+        run(SUPPORTED_RUBY_VERSIONS[rubyver], '-I' + LIBDIR, TEST_RUNNER)
+      rescue Gem2Deb::CommandFailed
         handle_test_failure(rubyver)
       end
     end
